@@ -66,6 +66,7 @@
 #include <QPixmap>
 #include <QMenu>
 #include <QCloseEvent>
+#include <QUrl>
 
 #include "editor.h"
 
@@ -99,6 +100,7 @@
 #include "restorecon.h"
 #include "mainwindow.h"
 #include "downloader.h"
+#include "downloader_process.h"
 #include "sqlrefpolicy.h"
 #include "semodule_dontaudit.h"
 #include "segatex_getseuserbyname.h"
@@ -160,6 +162,7 @@
 	seeprocess_o = 0;
 	restorecon_o = 0;
 	downloader_o = 0;
+	downloader_process_o = 0;
 	sqlrefpolicy_o = 0;
 	semodule_dontaudit_o = 0;
 	segatex_getseuserbyname_o = 0;
@@ -176,7 +179,7 @@
 	createStatusBar();
 	updateMenus();
 	readSettings();
-	setWindowTitle(tr("segatex-8.600"));
+	setWindowTitle(tr("segatex-8.610"));
 	QPixmap myIcon1 = QPixmap(":/images/icon.png");
 	this->setIcon(myIcon1);
 }
@@ -633,7 +636,7 @@ void MainWindow::paste()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-8.600</h2>"
+		tr("<h2>segatex-8.610</h2>"
 		"<p>Copyright &copy; 2007-2014"
 		"<p>Shintaro Fujiwara."
 		"<p><a href=\"http://sourceforge.net/projects/segatex\">segatex</a> is a SELinux tool"
@@ -1068,6 +1071,18 @@ void MainWindow::downloader()
 	downloader_o->raise();
 	downloader_o->setActiveWindow();
 }
+void MainWindow::downloader_process()
+{
+	if(!downloader_process_o) {
+		QUrl url_for_fedora("ftp://mirrors.kernel.org");
+		url_for_fedora.setPort(21);
+                QString version="new";
+		downloader_process_o = new DownloaderProcess(url_for_fedora,version,this);
+	}
+	downloader_process_o->show();
+	downloader_process_o->raise();
+	downloader_process_o->setActiveWindow();
+}
 void MainWindow::semodule_dontaudit()
 {
 	if(!semodule_dontaudit_o) {
