@@ -21,13 +21,13 @@
 #ifndef POLICYGENERATIONPROCESS_H
 #define POLICYGENERATIONPROCESS_H
 
-#include <qdialog.h>
-#include <q3textedit.h>
-#include <qlabel.h>
+#include <QDialog>
+#include <QTextEdit>
+#include <QLabel>
 
 class QLayout;
 class QCheckBox;
-class Q3TextEdit;
+class QTextEdit;
 class QPushButton;
 
 
