@@ -25,8 +25,6 @@
 #include <qmessagebox.h>
 //Added by qt3to4:
 #include <Q3TextStream>
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
 #include <QLabel>
 
 #include <unistd.h>
@@ -64,17 +62,17 @@ Restorecon::Restorecon(QWidget *parent, const char *name): QDialog(parent, name)
 	//set textEdit smanage such and such -l
 	restorecon_base_fcontext();
 
-	mainLayout = new Q3VBoxLayout(this);
+	mainLayout = new QVBoxLayout(this);
 	mainLayout->setMargin(11);
 
-	upperLayout = new Q3VBoxLayout;
+	upperLayout = new QVBoxLayout;
 	upperLayout->addWidget(textEdit1);
 
-	middleLayout = new Q3VBoxLayout;
-	leftLayout = new Q3HBoxLayout;
-	rightLayout = new Q3HBoxLayout;
-	thirdLayout = new Q3HBoxLayout;
-	fourthLayout = new Q3HBoxLayout;
+	middleLayout = new QVBoxLayout;
+	leftLayout = new QHBoxLayout;
+	rightLayout = new QHBoxLayout;
+	thirdLayout = new QHBoxLayout;
+	fourthLayout = new QHBoxLayout;
 	
 	leftLayout->addWidget(semanageEditLabel);
 	leftLayout->addWidget(semanageEditLineEdit);
@@ -85,7 +83,7 @@ Restorecon::Restorecon(QWidget *parent, const char *name): QDialog(parent, name)
 	middleLayout->addLayout(thirdLayout);
 	middleLayout->addLayout(fourthLayout);
 
-	footLayout = new Q3HBoxLayout;
+	footLayout = new QHBoxLayout;
 	footLayout->addStretch();
 	footLayout->addWidget(closeButton);
 
