@@ -41,7 +41,6 @@
 //default constructor
 SegatexYum::SegatexYum(QWidget *parent, const char *name): QDialog(parent, name)
 {
-
 		setCaption(tr("Yum SELinux"));
 		yumButton = new QPushButton(tr("&Install/Update"), this);
 		closeButton = new QPushButton(tr("&Close"), this);
@@ -66,7 +65,7 @@ SegatexYum::SegatexYum(QWidget *parent, const char *name): QDialog(parent, name)
 void SegatexYum::yum_clicked()
 {
 	selinux_yum_process = new SegatexYumProcess(this);
-	connect(selinux_yum_process, SIGNAL(yum_prosess_close_button_clicked()), this, SLOT(close()));
+	connect(selinux_yum_process, SIGNAL(yum_process_close_button_clicked()), this, SLOT(close()));
 	connect(closeButton, SIGNAL(clicked()), selinux_yum_process, SLOT(close()));
 	selinux_yum_process->show();
 	selinux_yum_process->raise();
