@@ -55,7 +55,6 @@ SegatexYumProcess::SegatexYumProcess(QWidget *parent, const char *name): QDialog
 
 	yum_install_base_process();
 	yum_update_base_process();
-
 }
 void SegatexYumProcess::yum_install_base_process()
 {
@@ -75,12 +74,9 @@ void SegatexYumProcess::yum_update_base_process()
 	connect(process1, SIGNAL(finished(int, QProcess::ExitStatus)),this,SLOT(processExited1(int, QProcess::ExitStatus)));
 	process1->start("yum -y update audit checkpolicy libsepol libselinux libselinux-devel libselinux-python libselinux-utils libsemanage mcstrans mod_selinux policycoreutils policycoreutils-gui policycoreutils-python selinux-doc selinux-policy selinux-policy-devel selinux-policy-minimum selinux-policy-mls selinux-policy-sandbox selinux-policy-targeted sepolgen setools-console setroubleshoot-server xguest");
 }
-
-
-
 void SegatexYumProcess::close_button_clicked()
 {
-	emit yum_prosess_close_button_clicked();
+	emit yum_process_close_button_clicked();
 
 }
 void SegatexYumProcess::readFromStdout()
