@@ -36,7 +36,6 @@
 #include <fstream>
 
 #include "semodule_core_process.h"
-//#include "editor.h"
 
 #include <iostream>
 using namespace std;
@@ -49,21 +48,21 @@ SemoduleCoreProcess::SemoduleCoreProcess(QWidget *parent, const char *name): QDi
 	textEdit1->setPaletteBackgroundColor(QColor(255,100,200));
 	textEdit2 = new QTextEdit(this);
 	textEdit2->setPaletteBackgroundColor(QColor(200,100,255));
-	moduleEditLabel = new QLabel(tr("Copy and paste module name:"), this );
+	moduleEditLabel = new QLabel(tr("module name:"), this );
 	moduleEditLineEdit = new QLineEdit( this );
 	moduleEditLineEdit->setText("");
 	moduleEditLineEdit->setPaletteBackgroundColor(QColor(255,100,200));
 
-	makeButton = new QPushButton(tr("Make this module"), this);
+	makeButton = new QPushButton(tr("Make this module\n(e.g. my.te (should be in /usr/share/segatex)"), this);
 	makeButton->setPaletteBackgroundColor(QColor(20,157,20));
 	connect(makeButton, SIGNAL(clicked()), this, SLOT(make_button_clicked()));
-	installButton = new QPushButton(tr("Install this module"), this);
+	installButton = new QPushButton(tr("Install this module(module name)"), this);
 	installButton->setPaletteBackgroundColor(QColor(220,120,120));
 	connect(installButton, SIGNAL(clicked()), this, SLOT(install_button_clicked()));
-	updateButton = new QPushButton(tr("Update this module"), this);
+	updateButton = new QPushButton(tr("Update this module(module name)"), this);
 	updateButton->setPaletteBackgroundColor(QColor(120,220,120));
 	connect(updateButton, SIGNAL(clicked()), this, SLOT(update_button_clicked()));
-	removeButton = new QPushButton(tr("Remove this module"), this);
+	removeButton = new QPushButton(tr("Remove this module(module name)"), this);
 	removeButton->setPaletteBackgroundColor(QColor(155,155,155));
 	connect(removeButton, SIGNAL(clicked()), this, SLOT(remove_button_clicked()));
 	closeButton = new QPushButton(tr("close"), this);
@@ -179,8 +178,8 @@ void SemoduleCoreProcess::semodule_core_base_process()
 	connect(process, SIGNAL(readyReadStandardOutput()),this,SLOT(readFromStdoutB()));
 	connect(process, SIGNAL(readyReadStandardError()),this,SLOT(updateOutputTextEditB()));
 	connect(process, SIGNAL(finished(int, QProcess::ExitStatus)),this,SLOT(processExitedB(int, QProcess::ExitStatus)));
-                //read_fp = popen("/usr/sbin/semodule -l", "r");
-                //read_fp = popen("/usr/sbin/semodule -l|grep permissive", "r");
+        //read_fp = popen("/usr/sbin/semodule -l", "r");
+        //read_fp = popen("/usr/sbin/semodule -l|grep permissive", "r");
 	//moduleEditLineEdit_str_pp = "/usr/sbin/semodule -l|grep permissive;&&/usr/sbin/semodule -l"; 
 	moduleEditLineEdit_str_pp = "/usr/sbin/semodule -l"; 
     	process->start("/bin/bash", QStringList() << "-c" << moduleEditLineEdit_str_pp);
@@ -255,143 +254,3 @@ void SemoduleCoreProcess::processExited(int exitCode, QProcess::ExitStatus exitS
 	process = 0;
 	this->setEnabled(true);
 }
-/*
-void SemoduleCoreProcess::semodule_core_base_process()
-{
-        #define PWD_BUF 8600
-        const char* module_list_file="/usr/share/segatex/module_list_2";
-        ofstream os;
-        os.open(module_list_file);
-        if(os){
-                FILE *read_fp;
-                #define SIZE_TMP 8600
-                char buffer[SIZE_TMP];
-                int chars_read;
-                memset(buffer, '\0', sizeof(buffer));
-                read_fp = popen("/usr/sbin/semodule -l", "r");
-                if(read_fp != NULL){
-                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
-                        while(chars_read>0){
-                                buffer[chars_read -1] = '\0';
-                                os << "Reading:-" << endl;
-                                os << buffer;
-                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
-                        }
-                        pclose(read_fp);
-                }
-        }
-	os.close();
-
-        const char* module_list_file2="/usr/share/segatex/module_list_1";
-        ofstream os2;
-        os2.open(module_list_file2);
-        if(os2){
-                FILE *read_fp;
-                #define SIZE_TMP 8600
-                char buffer[SIZE_TMP];
-                int chars_read;
-                memset(buffer, '\0', sizeof(buffer));
-                read_fp = popen("/usr/sbin/semodule -l|grep permissive", "r");
-                if(read_fp != NULL){
-                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
-                        while(chars_read>0){
-                                buffer[chars_read -1] = '\0';
-                                os2 << buffer;
-                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
-                        }
-                        pclose(read_fp);
-                }
-        }
-	os2.close();
-	//outputfile_str_common = module_list_file;
-	outputfile_str_common = "module_list*";
-	readFromOutputFile();
-
-}
-*/
-
-//this slot should be called from above slot
-/*
-void SemoduleCoreProcess::readFromOutputFile()
-{
-	/////////////////////////////////////////////////////////////
-	path = "/usr/share/segatex";
-	/////////////////////////////////////////////////////////////
-	forward_slash = "/";
-	dir.setPath(path);
-	dir_name = dir.absPath();
-	/////////////////////////////////////////////////////////////
-	dir.setFilter( QDir::Files );
-        dir.setSorting( QDir::Name );
-	files = dir.entryList(outputfile_str_common);
-	/////////////////////////////////////////////////////////////
-	it_d = files.begin();
-	int order_x;
-	order_x = 1;
-	textEdit1->clear();
-	while(it_d != files.end()){
-		name = *it_d;
-		file_interface_name = dir_name + forward_slash + name;
-		QFile file( file_interface_name );
-		if ( file.open( QIODevice::ReadOnly ) ) {
-			QTextStream stream( &file );
-			////////////////////////////////////////////
-			//button_numbers = 1;
-			if(order_x == 1)
-				textEdit1->append("##permissive domain list##");
-				textEdit1->append("");
-			if(order_x == 2)
-				textEdit1->append("##semodule list##");
-				textEdit1->append("");
-			//textEdit1->clear();
-			while ( !stream.atEnd() ) {
-				line_analized = stream.readLine(); // line of text excluding '\n'
-				textEdit1->append(line_analized);
-			}
-			//textEdit1->setCursorPosition(0,0);
-			file.close();
-			order_x++;
-			++it_d;
-		}else{
-			//do nothing
-		}
-	}
-}
-*/
-//this slot should be called from above slot
-/*
-void SemoduleCoreProcess::readFromOutputFile2()
-{
-	/////////////////////////////////////////////////////////////
-	//path = "./";
-	path = "/usr/share/segatex";
-	/////////////////////////////////////////////////////////////
-	forward_slash = "/";
-	dir.setPath(path);
-	dir_name = dir.absPath();
-	/////////////////////////////////////////////////////////////
-	dir.setFilter( QDir::Files );
-        dir.setSorting( QDir::Name );
-	files = dir.entryList(outputfile_str_common2);
-	/////////////////////////////////////////////////////////////
-	it_d = files.begin();
-		while(it_d != files.end()){
-			name = *it_d;
-			file_interface_name = dir_name + forward_slash + name;
-			QFile file( file_interface_name );
-			if ( file.open( QIODevice::ReadOnly ) ) {
-				QTextStream stream( &file );
-				////////////////////////////////////////////
-				textEdit2->clear();
-				while ( !stream.atEnd() ) {
-					line_analized = stream.readLine(); // line of text excluding '\n'
-					textEdit2->append(line_analized);
-				}
-				file.close();
-				++it_d;
-			}else{
-				//do nothing
-			}
-		}
-}
-*/
