@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2013 Shintaro Fujiwara 
+ * Copyright (C) 2007-2014 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,22 +21,20 @@
 #ifndef SEMODULECOREPROCESS_H
 #define SEMODULECOREPROCESS_H
 
-#include <qdialog.h>
-#include <qlayout.h>
-#include <qdir.h> 
-//#include <qvaluevector.h> 
-#include <qlabel.h> 
-#include <q3textedit.h>
-//Added by qt3to4:
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
+#include <QDialog>
+#include <QLayout>
+#include <QDir> 
+#include <QLabel> 
+#include <QTextEdit>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
+#include <QProcess> 
 
 
 class QLayout;
-class Q3TextEdit;
+class QTextEdit;
 class QLineEdit;
 class QPushButton;
-class Q3Process;
 
 class SemoduleCoreProcess: public QDialog 
 {
@@ -60,24 +58,35 @@ private slots:
 	void install_button_clicked_process(QString textEdit1_str);
 	void update_button_clicked_process(QString textEdit1_str);
 	void remove_button_clicked_process(QString textEdit1_str);
-	void readFromOutputFile();
-	void readFromOutputFile2();
+	//void readFromOutputFile();
+	//void readFromOutputFile2();
+//newly added
+	void readFromStdoutB();
+	void updateOutputTextEditB();
+        void processExitedB(int, QProcess::ExitStatus);
+	void readFromStdout();
+	void updateOutputTextEdit();
+        void processExited(int, QProcess::ExitStatus);
+//end newly added
 public:
 private:
+//newly added
+	QProcess *processB;
+	QProcess *process;
+//end newly added
 	QPushButton *makeButton;
 	QPushButton *installButton;
 	QPushButton *updateButton;
 	QPushButton *removeButton;
 	QPushButton *closeButton;
-	Q3TextEdit *textEdit1;
-	Q3TextEdit *textEdit2;
-	Q3Process *process;
+	QTextEdit *textEdit1;
+	QTextEdit *textEdit2;
 
-	Q3HBoxLayout *mainLayout;
-	Q3VBoxLayout *leftLayout;
-	Q3VBoxLayout *middleLayout;
-	Q3VBoxLayout *rightLayout;
-	Q3VBoxLayout *footLayout;
+	QHBoxLayout *mainLayout;
+	QVBoxLayout *leftLayout;
+	QVBoxLayout *middleLayout;
+	QVBoxLayout *rightLayout;
+	QVBoxLayout *footLayout;
 
         QDir dir;
         QString path;
