@@ -21,24 +21,25 @@
 #ifndef SEMODULEDONTAUDIT_H
 #define SEMODULEDONTAUDIT_H
 
-#include <q3textedit.h>
-#include <q3process.h>
-#include <qdialog.h>
-#include <qlayout.h>
-#include <qcheckbox.h>
-#include <qlabel.h>
+#include <QTextEdit>
+#include <QDialog>
+#include <QLayout>
+#include <QCheckBox>
+#include <QLabel>
 #include <QButtonGroup>
 #include <QPushButton>
 #include <QGroupBox>
-#include <qradiobutton.h>
+#include <QRadioButton>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include <QDateTime>
 #include <QString>
+#include <QProcess>
+#include <QDir>
 
 class QLayout;
 class QMessageBox;
-class Q3TextEdit;
+class QTextEdit;
 class SemoduleDontauditProcess;
 
 class SemoduleDontaudit: public QDialog
@@ -62,9 +63,9 @@ private slots:
 	int readFromOutputFile_and_return_str();
 private:
 	int check_int;
-	Q3Process *process;
-	Q3Process *process2;
-	Q3TextEdit *textEdit1;
+	QProcess *process;
+	QProcess *process2;
+	QTextEdit *textEdit1;
         QDir dir;
         QString test_str;
         QString path;
